#
# spec file for package THE
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           THE
Version:        4.0
Release:        1.153
Summary:        The Hessling Editor (z/VM-CMS xedit clone)
# getch.c and getch.h state that
# Permission is hereby granted to copy, distribute or otherwise
# use any part of this package as long as you do not try to make
# money from it or pretend that you wrote it.
# see boo#982229
License:        GFDL-1.1-only AND GPL-2.0-or-later AND SUSE-Freeware
URL:            https://hessling-editor.sourceforge.net/
Source0:        https://sourceforge.net/projects/hessling-editor/files/hessling-editor/%{version}/the-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  Regina-REXX-devel
BuildRequires:  distribution-release
BuildRequires:  flex
BuildRequires:  lsb-release
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ncurses)

%description
THE is a text editor that uses both command line commands and key bindings
to operate. It is intended to be similar to the z/VM-CMS system editor,
XEDIT, and to Mansfield Software's, KEDIT

%package doc
Summary:        The Hessling Editor (z/VM-CMS xedit clone)
BuildArch:      noarch

%description doc
This package contains the documentation for the THE (The Hessling Editor)
package.

%prep
%autosetup -n the-%{version}

%build
%configure \
  --with-curses=ncurses \
  --with-rexx=regina
PATH=${PATH}:$(pwd)
%make_build

%install
%make_install
# Do not ship backup file
rm -rf doc/THE_Help_head.bak

%files
%license COPYING
%doc FAQ README TODO HISTORY
%{_bindir}/the
%{_bindir}/the-con
%{_datadir}/the/
%{_mandir}/man1/the.1%{?ext_man}

%files doc
%defattr(644,root,root)
%doc app*.htm*
%doc appendix.*
%doc doc/*

%changelog
* Fri Jun  2 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- Update to version 4.0:
  * Increase maximum SELECT level to 50000
  * Add completer.the for better command line file completion lookup
  * Add remote.the to enable editing files on remote server using ssh/scp
  * Add VARIANT to EXTRACT/QUERY to determine which THE variant you are running
  * Add MOUSECLICK to SET/EXTRACT/QUERY to set/query the time interval in milliseconds
    that a press/release of the mouse button converts into a mouse button click
  * Add GETSTEM, PUTSTEM, GETSTEMF, PUTSTEMF to EDITV command
  * Enable EXTRACT /SELECT to return maximum SELECT level in SELECT.3
* Mon Jun  6 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.3~RC8:
  * No upstream changelog available
* Thu Nov 26 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.3~RC7:
  * No upstream changelog available
* Tue Feb 20 2018 mpluskal@suse.com
- Enable additional functionality
- Run spec-cleaner
* Thu Feb 16 2017 mpluskal@suse.com
- Do not build pdf documentation as it contains timestamps
- Make doc subpackage noarch
* Mon Feb  6 2017 dimstar@opensuse.org
- Switch to libncurses.so.6:
  + export ncurses5_config=%%{_bindir}/ncurses6-config.
* Tue Jul  5 2016 toddrme2178@gmail.com
- Fix Group tag.
* Tue May 31 2016 mpluskal@suse.com
- Update licensing information
* Mon May 23 2016 jengelh@inai.de
- Set group for -doc subpackage
* Sun May 15 2016 mpluskal@suse.com
- Update to 3.3~RC4
- Drop no longer needed patches
  * THE-3.1-open.patch
  * THE-3.2-lib64.patch
  * THE-3.2-nostrictaliasing.patch
* Mon May  2 2016 mpluskal@suse.com
- Rename fro the to THE
* Wed Apr 20 2016 mpost@suse.com
- Upgraded to version 3.2
- Renamed THE-3.1-lib64.patch to THE-3.2-lib64.patch and updated
  it to fit the new version.
- Renamed THE-3.1-nostrictaliasing.diff to THE-3.2-nostrictaliasing.patch
  and updated it to fit the new version.
- Renamed THE-3.1-open.diff to THE-3.1-open.patch
- Removed obsolete patches:
  THE-3.1-DESTDIR.diff
  THE-3.1-same-variable-used-twice.patch
- Added a symbolic link of /usr/bin/the to point to the new name
  /usr/bin/nthe
- Added a symbolic link of /usr/share/man/man1/the.1.gz to point to the new name
  /usr/share/man/man1/nthe.1.gz
- Broke the documentation out into a doc package.
- Replaced hardcoded paths and version numbers with RPM macros.
- Version 3.2 didn't have a separate PDF manual, but it could be generated with
  a "make pdf" command, so that was added to the spec file.
- Adding "make pdf" required that "BuildRequires: htmldoc" was added to the
  spec file.
- Added a the-rpmlintrc file to suppress warnings about using "the" in the
  summary.
- Replaced manual ./configure with %%configure.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Sat Jan 12 2008 coolo@suse.de
- fix build with glibc 2.7
* Thu Mar 29 2007 meissner@suse.de
- added buildrequires ncurses-devel
* Thu Jan 18 2007 ssommer@suse.de
- fix same variable used twice error
- renamed the-3.1.spec -> the.spec
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue May 10 2005 meissner@suse.de
- use RPM_OPT_FLAGS. Fixed the bug the strict-aliasing
  code exposed (now using short instead of short*).
* Fri May 21 2004 ro@suse.de
- add -fno-strict-aliasing
* Mon Jan 12 2004 adrian@suse.de
- added %%defattr
* Tue Aug  5 2003 mge@suse.de
- fixed lib64 patch
* Tue Aug  5 2003 mge@suse.de
- added pdf-documentation
* Tue May 27 2003 ro@suse.de
- fix man-page installation and add man-page to filelist
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Aug 16 2002 mge@suse.de
- fix building on 64bit
* Thu Aug 15 2002 mge@suse.de
- update to 3.1
* Mon May 27 2002 meissner@suse.de
- %%_lib fixes again. (coolos stuff did not work).
* Tue May 21 2002 coolo@suse.de
- update config and add lib64 patch
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Wed Jul  5 2000 mge@suse.de
- patch for regina 2.0.0
* Sun Feb 13 2000 mge@suse.de
- update to 3.0
- group tag
* Tue Dec 14 1999 uli@suse.de
- added "#undef PPC" to the.h to avoid conflicts with PPC identifier
* Mon Oct 25 1999 mge@suse.de
- moved /usr/THE to /usr/share/THE,
- removed useless "requires"
* Mon Oct 25 1999 mge@suse.de
- initial SuSE-RPM
